@@ -8,11 +8,12 @@ from serverly.utils import *
 
 from fileloghelper import Logger
 
-version = "0.0.7"
+version = "0.0.8"
 description = "A really simple-to-use HTTP-server"
 address = ("localhost", 8080)
 name = "PyServer"
-logger: Logger = None
+logger = Logger("serverly.log", "serverly", False, True)
+logger.header(True, True, description, version=True)
 
 
 class Handler(BaseHTTPRequestHandler):
@@ -266,8 +267,6 @@ def static_page(file_path, path):
 
 
 def start(superpath="/"):
-    logger = Logger(name + ".log", name, False, True)
-    logger.header(True, True, description, version=True)
     _sitemap.superpath = superpath
     _server = Server(address)
     _server.run()
